#include <iostream>
#include <unordered_map>
#include <random>

#include "io.h"
#include "sims.h"
#include "motions/bimodalangle.h"
#include "motions/isosmallangle.h"
#include "motions/random.h"
#include "motions/tetrahedral.h"
#include "times/delta.h"
#include "times/lognormal.h"


int main (const int argc, char *argv[]) {
    Arguments args;
    try {
        args = parse_args(argc, argv);
    } catch (std::runtime_error& error) {
        std::cerr << error.what() << std::endl;
        return 1;
    }


    std::unordered_map parameter { read_parameter(args.parameter_file) };



    std::random_device rd;
    std::mt19937_64 rng(rd());

    // auto motion = BimodalAngle(1, 1, 2, 30, 0.98, rng);
    // auto motion = TetrahedralJump(rng);
    // auto motion = RandomJump(rng);
    auto motion = SmallAngle(1, 1, 1, rng);

    // auto dist = DeltaDistribution(rng);
    auto dist = LogNormalDistribution(1, 2, rng);


    if (args.spectrum) {
       run_spectrum(parameter, motion, dist);
    }
    if (args.ste) {
        run_ste(parameter, motion, dist);
    }
}
